(defun c:ar3sysmark ()
  (cond ((/= (strcase (getvar "dwgname")) "ALOHA3.DWG")
	 (princ "\nIncorrect drawing loaded - open ALOHA3 from the accuren3/tutorials folder\n")
	 )
	((null (arloaded?))
	 (princ "\nAccuRender not loaded, type AR3 at the command prompt, exit AccuRender and try again\n")
	 )
	((< (nth 2 (ar3_version)) 261)
	 (princ "\nPlease install the most current version of AccuRender - build 261 or above\n")
	 )
	(T
	 (run_ar3sysmark)
	 )
	)
  (princ)
  )

(defun run_ar3sysmark ( / ocm flags endtime starttime translate_time radiosity_time raytrace_time)
  (setq ocm (getvar "cmdecho"))		; save command echo mode
  (setvar "cmdecho" 0)			; and switch it off
  (command "_.undo" "_begin")
  (command "_.-layer" "_f" "trees" "")
  (setq flags (ar3_getvar 1300))	
  (if (> flags 8000)			
    (setq flags (- flags 8192))		
  )
  (ar3_setvar 1300 flags)		
  (ar3_setvar 1301 640) ;set the X resolution
  (ar3_setvar 1302 320) ;and the Y resolution
  (ar3_setvar 1325 4)	;set to very high
  (cond (
	 (and
	   (setq translate_time (translate_test))
	   (setq radiosity_time (radiosity_test translate_time))
	   (setq raytrace_time (raytrace_test))
	   )
	 (textscr)
	 (princ (strcat "\nThe AR3Mark results are as follows:\n"
		 "\nTranslation time: " (itoa (fix translate_time)) " seconds"
		 "\nRadiosity time: " (itoa (fix radiosity_time)) " seconds"
		 "\nRaytrace time: " (itoa (fix raytrace_time)) " seconds"
		 "\n\nTotal time: " (itoa (fix (+ translate_time radiosity_time raytrace_time))) " seconds")
		)
	 )
	(T
	 (princ "\nThe process was cancelled.\n")
	 )
	)
  (command "_.undo" "_end")
  (setvar "cmdecho" ocm)
  )

(defun translate_test ( / clear starttime endtime time)
  (setq clear T)
  (setq starttime (getvar "date"))
  (ar3_method 0)
  (repeat 10
    (if clear
      (progn
	(ar3_force_reload 1)
	(ar3_calibration_mode 1)
	(setq clear (> (c:ar3_rt) 0))
	)
      )
    )
  (setq endtime (getvar "date"))
  (if clear
    (setq time (* 86400 (- endtime starttime)))
    (setq time nil)
    )
  )

(defun radiosity_test (translate_time / clear starttime endtime time totaltime repeats)
  (setq totaltime 0.0
	repeats 0
	clear T)
  (ar3_setvar 1201 100)
  (while (and clear (< totaltime 180))
    (setq repeats (1+ repeats))
    (setq starttime (getvar "date"))
    
    (setq clear (> (c:ar3_rad) 0))
    (setq endtime (getvar "date"))
    (if clear
      (setq time (- (* 86400 (- endtime starttime)) (/ translate_time 10))
	    totaltime (+ time totaltime))
      (setq time nil)
      )
    )

  (if time
    (/ totaltime repeats)
    time)
  )

(defun raytrace_test ( / clear starttime endtime time totaltime repeats)
  (setq totaltime 0.0
	repeats 0
	clear T)
  (while (and clear (< totaltime 180))
    (setq repeats (1+ repeats))
    (setq starttime (getvar "date"))
    (setq clear (> (c:ar3_rt) 0))
    (setq endtime (getvar "date"))
    (if clear
      (setq time (* 86400 (- endtime starttime))
	    totaltime (+ time totaltime))
      (setq time nil)
      )
    )
  
  (if time
    (/ totaltime repeats)
    time)
  )

 




(defun arloaded? ()
    (cond ((member "accuren3_2000.arx" (arx)))
	  ((member "accuren3_2000i.arx" (arx)))
	  ((member "accuren3_2000j.arx" (arx)))
	  ((member "accuren3_2000d.arx" (arx)))
	  ((member "accuren3_r14.arx" (arx)))
	  ((member "accuren3_r14i.arx" (arx)))
	  ((member "accuren3_r14j.arx" (arx)))
	  ((member "accuren3_r14d.arx" (arx)))
	  ((member "ar3_2004.arx" (arx)))
	  ((member "ar3_2004d.arx" (arx)))
	  ((member "ar3_2004i.arx" (arx)))
	  ((member "ar3_2004j.arx" (arx)))
	  )
  )
